==> ejc-bfyjerp-api-3.0.0-20241121.071814-57-sources.jar: com/ejianc/business/oa/vo/CertHumanChangeVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 人力行政-证书人员申请表-变更
 * 
 * @author generator
 * 
 */
public class CertHumanChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long applyId; // 申请表
    private String code; // 编号
    private String name; // 员工名称
    private Integer sex; // 性别 1：男 2：女
    private Integer age; // 年龄
    private Long orgId; // 组织ID
    private String orgName; // 组织
    private Integer humanType; // 人员类别
    private String humanTypeName; // 人员类别
    private String idCard; // 身份证号码
    private String cert; // 证书情况
    private String certName; // 证书情况
    private BigDecimal certMny; // 证书费用
    private Integer payType; // 付款方式
    private String payTypeName; // 付款方式
    private Integer titleQuery; // 职称网查
    private String titleQueryName; // 职称网查
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Integer changeVersion; // 变更版本
    private String compatibility; // 配合度

    public String getCompatibility() {
        return compatibility;
    }

    public void setCompatibility(String compatibility) {
        this.compatibility = compatibility;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public String getCert() {
        return cert;
    }
    @ReferDeserialTransfer
    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }
    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }
    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }
    public Integer getTitleQuery() {
        return titleQuery;
    }

    public void setTitleQuery(Integer titleQuery) {
        this.titleQuery = titleQuery;
    }
    public String getTitleQueryName() {
        return titleQueryName;
    }

    public void setTitleQueryName(String titleQueryName) {
        this.titleQueryName = titleQueryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250408.070234-188-sources.jar: com/ejianc/business/oa/vo/CertHumanChangeVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 人力行政-证书人员申请表-变更
 * 
 * @author generator
 * 
 */
public class CertHumanChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long applyId; // 申请表
    private String code; // 编号
    private String name; // 员工名称
    private Integer sex; // 性别 1：男 2：女
    private Integer age; // 年龄
    private Long orgId; // 组织ID
    private String orgName; // 组织
    private Integer humanType; // 人员类别
    private String humanTypeName; // 人员类别
    private String idCard; // 身份证号码
    private String cert; // 证书情况
    private String certName; // 证书情况
    private BigDecimal certMny; // 证书费用
    private Integer payType; // 付款方式
    private String payTypeName; // 付款方式
    private Integer titleQuery; // 职称网查
    private String titleQueryName; // 职称网查
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Integer changeVersion; // 变更版本
    private String compatibility; // 配合度

    private String province; // 省份
    private String purpose; // 用途

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getPurpose() {
        return purpose;
    }

    public void setPurpose(String purpose) {
        this.purpose = purpose;
    }
    public String getCompatibility() {
        return compatibility;
    }

    public void setCompatibility(String compatibility) {
        this.compatibility = compatibility;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public String getCert() {
        return cert;
    }
    @ReferDeserialTransfer
    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }
    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }
    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }
    public Integer getTitleQuery() {
        return titleQuery;
    }

    public void setTitleQuery(Integer titleQuery) {
        this.titleQuery = titleQuery;
    }
    public String getTitleQueryName() {
        return titleQueryName;
    }

    public void setTitleQueryName(String titleQueryName) {
        this.titleQueryName = titleQueryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    
}
